package org.waxworlds.importcontacts;

import java.util.Stack;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;

public class ImportContacts extends Activity
{
	public static final int STATE_NONE = 0;
	public static final int STATE_IMPORT_VCF = 1;
	public static final int STATE_MERGE = 2;
	public static final int STATE_DOIT = 3;

	private Stack< Integer > _stateStack;

	/** Called when the activity is first created. */
	@Override
    public void onCreate(Bundle savedInstanceState)
    {
		super.onCreate(savedInstanceState);

		_stateStack = new Stack< Integer >();

		startState( STATE_IMPORT_VCF );
    }

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data)
	{
		super.onActivityResult(requestCode, resultCode, data);

		// quit?
		if( resultCode == RESULT_CANCELED ) {
			finish();
		}
		else {
			int newState = STATE_NONE;
			if( data != null ) {
				Bundle extras = data.getExtras();
				if( extras != null ) {
					Integer tmp = extras.getInt( "nextstate" );
					if( tmp != null ) {
						newState = tmp.intValue();
					}
				}
			}
			startState( newState );
		}
	}

	private void startState( int newState )
	{
		if( newState == STATE_NONE )
		{
			// we're going back, so pop top state off stack
			_stateStack.pop();
			newState = ( (Integer)_stateStack.peek() ).intValue();
		}
		else
		{
			// push new state on state
			_stateStack.push( new Integer( newState ) );
		}

		// figure out the class
		Class cls = null;
		switch( newState ) {
		case STATE_IMPORT_VCF: cls = ImportVCF.class; break;
		case STATE_MERGE: cls = Merge.class; break;
		case STATE_DOIT: cls = Doit.class; break;
		}

		// start activity
		Intent i = new Intent( this, cls );
		if( _stateStack.size() > 1 ) i.putExtra( "backstate", true );
		startActivityForResult( i, 0 );
	}
}